@@ -1,6 +1,6 @@
 #' Computes the gradient of distsum function
 #'
-#' The gradient function for the min-sum location problem.
+#' The gradient of the objective function for the min-sum location problem.
 #'
 #' @name distsumgra
 #' @aliases distsumgra distsumgra,loca.p-method
@@ -12,7 +12,7 @@
 #' @param lp If given, then \eqn{l_p} norm will be used instead of the Euclidean norm.
 #' @param partial If (x,y) is a demand point \code{partial=T} means ignore such point to compute the gradient. This option is mainly for internal use.
 #' @return 
-#' \code{distsumgra} returns the gradient vector of the function of the min-sum location problem, \eqn{\sum_{a_i \in o} w_i d(a_i, (x,y))}, where \eqn{d(a_i, (x,y))} gives the euclidean or the \eqn{l_p} distances between \eqn{a_i} and the point \eqn{(x,y)}.
+#' \code{distsumgra} returns the gradient vector of the objective function of the min-sum location problem, \eqn{\sum_{a_i \in o} w_i d(a_i, (x,y))}, where \eqn{d(a_i, (x,y))} gives the euclidean or the \eqn{l_p} distances between \eqn{a_i} and the point \eqn{(x,y)}.
 #'
 #' @examples
 #' # A new unweighted loca.p object
@@ -42,7 +42,7 @@ setMethod("distsumgra", "loca.p", function(o, x=0, y=0, lp=numeric(0), partial=F
    {
      if (length(lp) == 0) return(distsuml2gra(o=o, x=x, y=y, partial=partial))
      else if (lp >= 1) return(distsumlpgra(o=o, x=x, y=y, p=lp, partial=partial))
-     else stop(paste(lp, gettext("is not a valid value for lp, use 1 <= lp", domain = "R-orloca")))
+     else stop(paste(lp, gettext("is not a valid value for lp, use 1 <= lp")))
    }
 )
 
