@@ -16,11 +16,10 @@
 #' @param x The x coordinate of the point to be evaluated.
 #' @param y The y coordinate of the point to be evaluated.
 #' @param p The \eqn{l_p} norm to use.
-#' @param partial If (x,y) is a demand point \code{partial=T} means ignore such point to compute the gradient. This option is mainly for internal use.
 #' @return
 #' \code{distsumlp} returns the objective function of the min-sum location problem with \eqn{l_p} norm, \eqn{\sum_{a_i \in o} w_i d(a_i, (x,y))}, where \eqn{d(a_i, (x,y))} gives the distances between \eqn{a_i} and the point \eqn{(x,y)} using \eqn{l_p} norm.
 #'
-#' \code{distsumlpgra} returns the gradient vector of the function \code{distsumlp}.
+#' \code{distsumlpgra} returns the gradient vector of the function \code{distsumlp}. If \eqn{(x,y)} is a demand point \code{partial=T} means ignore such point to compute the gradient. This option is mainly for internal use.
 #' 
 #' @seealso See also \code{\link{distsum}}, \code{\link{orloca-package}} and \code{\link{distsumlpmin}}.
 #' 
@@ -35,7 +34,7 @@ setGeneric("distsumlp", function(o, x=0, y=0, p=2) standardGeneric("distsumlp"))
 setMethod("distsumlp", "loca.p", function(o, x=0, y=0, p=2)
    {
      if (p>=1) return(sum(o@w*(abs(o@x-x)^p+abs(o@y-y)^p)^(1/p)))
-     else stop(paste(p, gettext("is not a valid value for p, use 1 <= p", domain = "R-orloca")))
+     else stop(paste(p, gettext("is not a valid value for p, use 1 <= p")))
    }
 )
 
@@ -51,6 +50,6 @@ setMethod("distsumlpgra", "loca.p", function(o, x=0, y=0, p=2, partial=F)
        n<- o@w*(abs(x-o@x)^p+abs(y-o@y)^p)^(1/p-1)
        c(sum(sign(x-o@x)*abs(x-o@x)^(p-1)*n, na.rm=partial), sum(sign(y-o@y)*abs(y-o@y)^(p-1)*n, na.rm=partial))
      }
-     else stop(paste(p, gettext("is not a valid value for p, use 1 <= p", domain = "R-orloca")))
+     else stop(paste(p, gettext("is not a valid value for p, use 1 <= p")))
    }
 )
