@@ -11,8 +11,10 @@
 #' An alternative form is \code{new("loca.p", x, y, w = numeric(0), label = "")}.
 #'
 #' The lengths of \code{x} and \code{y} vector must be equals.
-#' The length of \code{w} must be equal to the previous ones or must be 0.
+#' The length of \code{w} must be equal to the previous ones or must be 0, or should be omitted.
 #' NA's values are not allowed at any of the arguments.
+#' 
+#' \code{summary(x)} returns a summary of the \code{x} \code{loca.p} object and \code{print(x)} prints the \code{x} \code{loca.p} object in table format.
 #'
 #' @keywords classes optimize
 #'
@@ -21,7 +23,6 @@
 #' @param w is a vector of weights of the demand points. If w is omitted then all weights are considered as 1.
 #' @param label If given, it is the label of the new object.
 #' @return If the arguments have valid values, it returns a new object of class \code{loca.p}, else it returns an error.
-#' \code{summary(x)} returns a summary of the \code{x} \code{loca.p} object and \code{print(x)} prints the \code{x} \code{loca.p} object in table format.
 #' @examples
 #' # A new unweighted loca.p object
 #' loca <- loca.p(x = c(-1, 1, 1, -1), y = c(-1, -1, 1, 1))
@@ -52,11 +53,11 @@ setValidity("loca.p",
                     if (length(object@x)==length(object@w) || length(object@w)==0)
                     {
                         if (!any(is.na(object@x)) && !any(is.na(object@y)) && !any(is.na(object@w))) TRUE
-                        else paste(gettext("NA's values are not allowed", domain = "R-orloca"), sep="")
+                        else paste(gettext("NA's values are not allowed"), sep="")
                     }
-                    else paste(gettext("The length of w (", domain = "R-orloca"), length(object@w), gettext(") should be the same as the length of x, and y (", domain = "R-orloca"), length(object@x) ,gettext(") or 0", domain = "R-orloca"))
+                    else paste(gettext("The length of w ("), length(object@w), gettext(") should be the same as the length of x, and y ("), length(object@x) ,gettext(") or 0"))
                 }
-                else paste(gettext("The length of x and y are different", domain = "R-orloca"), length(object@x), ", ", length(object@y))
+                else paste(gettext("The length of x and y are different"), length(object@x), ", ", length(object@y))
             }
             )
 
